import { FunctionComponent, ComponentProps } from 'react';
import { SIWEProvider } from 'starkwebkit';
import type { IncomingMessage, ServerResponse } from 'http';
import { IronSession, IronSessionOptions } from 'iron-session';
import { NextApiHandler, NextApiRequest, NextApiResponse } from 'next';
import { Chain, Transport, Hex } from 'starkweb';
type RouteHandlerOptions = {
    afterNonce?: (req: NextApiRequest, res: NextApiResponse, session: NextSIWESession<{}>) => Promise<void>;
    afterVerify?: (req: NextApiRequest, res: NextApiResponse, session: NextSIWESession<{}>) => Promise<void>;
    afterSession?: (req: NextApiRequest, res: NextApiResponse, session: NextSIWESession<{}>) => Promise<void>;
    afterLogout?: (req: NextApiRequest, res: NextApiResponse) => Promise<void>;
};
type NextServerSIWEConfig = {
    config?: {
        chains: readonly [Chain, ...Chain[]];
        transports?: Record<number, Transport>;
    };
    session?: Partial<IronSessionOptions>;
    options?: RouteHandlerOptions;
};
type NextClientSIWEConfig = {
    apiRoutePrefix: string;
    statement?: string;
};
type NextSIWESession<TSessionData extends Object = {}> = IronSession & TSessionData & {
    nonce?: string;
    address?: string;
    chainId?: Hex;
};
type NextSIWEProviderProps = Omit<ComponentProps<typeof SIWEProvider>, 'getNonce' | 'createMessage' | 'verifyMessage' | 'getSession' | 'signOut' | 'data' | 'signIn' | 'status' | 'resetStatus'>;
type ConfigureServerSIWEResult<TSessionData extends Object = {}> = {
    apiRouteHandler: NextApiHandler;
    getSession: (req: IncomingMessage, res: ServerResponse) => Promise<NextSIWESession<TSessionData>>;
};
type ConfigureClientSIWEResult<TSessionData extends Object = {}> = {
    Provider: FunctionComponent<NextSIWEProviderProps>;
};
export declare const configureServerSideSIWE: <TSessionData extends Object = {}>({ config, session: { cookieName, password, cookieOptions, ...otherSessionOptions }, options: { afterNonce, afterVerify, afterSession, afterLogout }, }: NextServerSIWEConfig) => ConfigureServerSIWEResult<TSessionData>;
export declare const configureClientSIWE: <TSessionData extends Object = {}>({ apiRoutePrefix, statement, }: NextClientSIWEConfig) => ConfigureClientSIWEResult<TSessionData>;
export {};
